IAbortSignal class abstract

Represents a signal that can be monitored to determine if a request has been aborted.

Implementers

Constructors

IAbortSignal()

Properties

aborted → bool?
Indicates if the request has been aborted.
no setter
hashCode → int
The hash code for this object.
no setterinherited
onabort ↔ OnAbort?
Set this to a handler that will be invoked when the request is aborted.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited