BinaryMessageFormat class

Constructors

BinaryMessageFormat()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

recordSeparator ↔ String
getter/setter pair

Static Methods

parse(Uint8List input) → List<Uint8List>
write(Uint8List output) → Uint8List

Constants

RecordSeparatorCode → const int