AbortError class

Error thrown when an action is aborted.

Implemented types

Constructors

AbortError([String message = "An abort occurred."])
Constructs a new instance of AbortError.

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
The error message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited