HttpError class

Error thrown when an HTTP request fails.

Implemented types

Constructors

HttpError(String? errorMessage, num statusCode)
Constructs a new instance.

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → num
The HTTP status code represented by this error.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited