HandshakeProtocol class

@private

Constructors

HandshakeProtocol()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseHandshakeResponse(Object? data) → ParseHandshakeResponseResult
Parse the handshake reponse data: either a string (json) or a Uint8List (binary) of the handshake response data.
toString() → String
A string representation of this object.
inherited
writeHandshakeRequest(HandshakeRequestMessage handshakeRequest) → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited