HandshakeRequestMessage class

private

Constructors

HandshakeRequestMessage(String protocol, int version)

Properties

hashCode → int
The hash code for this object.
no setterinherited
protocol → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited