HttpConnection class

Implemented types

Constructors

HttpConnection(String url, {required HttpConnectionOptions options})

Properties

baseUrl ↔ String?
getter/setter pairoverride
connectionId ↔ String?
getter/setter pairoverride
features ↔ ConnectionFeatures?
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
onclose ↔ OnClose?
getter/setter pairoverride
onreceive ↔ OnReceive?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(Object? data) → Future<void>
override
start({TransferFormat? transferFormat}) → Future<void>
override
stop({Exception? error}) → Future<void>?
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

maxRedirects → int
final

Static Methods

transportMatches(HttpTransportType? requestedTransport, HttpTransportType actualTransport) → bool