NegotiateResponse class

Constructors

NegotiateResponse(String? connectionId, String? connectionToken, int? negotiateVersion, List<AvailableTransport>? availableTransports, String? url, String? accessToken, String? error)
NegotiateResponse.fromJson(Map<String, dynamic> json)

Properties

accessToken → String?
final
availableTransports ↔ List<AvailableTransport>?
getter/setter pair
connectionId ↔ String?
getter/setter pair
connectionToken ↔ String?
getter/setter pair
error → String?
final
hasAccessToken → bool
no setter
hasConnectionId → bool
no setter
hasConnectionTokenId → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNegotiateVersion → bool
no setter
isConnectionResponse → bool
no setter
isErrorResponse → bool
no setter
isRedirectResponse → bool
no setter
negotiateVersion ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited