TransportSendQueue class

Constructors

TransportSendQueue(ITransport? transport)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transport → ITransport?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(Object? data) → Future<void>
stop() → Future<void>?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

concatBuffers(List<Uint8List?> arrayBuffers) → Uint8List