HttpConnectionOptions class

Options provided to the 'withUrl' method on HubConnectionBuilder to configure options for the HTTP-based transports.

Constructors

HttpConnectionOptions({SignalRHttpClient? httpClient, Object? transport, Logger? logger, AccessTokenFactory? accessTokenFactory, MessageHeaders? headers, bool logMessageContent = false, bool skipNegotiation = false, int requestTimeout = 2000})

Properties

accessTokenFactory ↔ AccessTokenFactory?
A function that provides an access token required for HTTP Bearer authentication.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ MessageHeaders?
A MessageHeaders that provides default headers for HTTP Requests
getter/setter pair
httpClient ↔ SignalRHttpClient?
An SignalRHttpClient that will be used to make HTTP requests.
getter/setter pair
logger ↔ Logger?
Configures the logger used for logging.
getter/setter pair
logMessageContent ↔ bool
A boolean indicating if message content should be logged.
getter/setter pair
requestTimeout ↔ int
An int that reflects the time to wait for a request to complete before throwing a TimeoutError. Measured in milliseconds.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipNegotiation ↔ bool
A boolean indicating if negotiation should be skipped.
getter/setter pair
transport ↔ Object?
An HttpTransportType or ITransport value specifying the transport to use for the connection If transport is null and the server supports all transport protocols than HttpTransportType.WebSockets is used.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited