CloseMessage class

A hub message indicating that the sender is closing the connection.

If {@link @microsoft/signalr.CloseMessage.error} is defined, the sender is closing the connection due to an error.

Inheritance

Constructors

CloseMessage({String? error, bool? allowReconnect})

Properties

allowReconnect → bool?
If true, clients with automatic reconnects enabled should attempt to reconnect after receiving the CloseMessage. Otherwise, they should not. */
final
error → String?
The error that triggered the close, if any.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → MessageType
A MessageType value indicating the type of this message.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited