CompletionMessage class

A hub message representing the result of an invocation.

Inheritance

Constructors

CompletionMessage({String? error, Object? result, MessageHeaders? headers, String? invocationId})

Properties

error → String?
The error produced by the invocation, if any.
final
hashCode → int
The hash code for this object.
no setterinherited
headers → MessageHeaders
A {@link @microsoft/signalr.MessageHeaders} dictionary containing headers attached to the message.
finalinherited
invocationId → String?
The ID of the invocation relating to this message.
finalinherited
result → Object?
The result produced by the invocation, if any.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → MessageType
A MessageType value indicating the type of this message.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited