IHubProtocol class abstract

A protocol abstraction for communicating with SignalR Hubs.

Implementers

Constructors

IHubProtocol(String name, int number, TransferFormat transferFormat)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the protocol. This is used by SignalR to resolve the protocol between the client and server.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transferFormat → TransferFormat
The TransferFormat of the protocol. */
final
version → int
The version of the protocol.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseMessages(Object input, Logger? logger) → List<HubMessageBase>
Creates an array of {@link @microsoft/signalr.HubMessage} objects from the specified serialized representation.
toString() → String
A string representation of this object.
inherited
writeMessage(HubMessageBase message) → Object
Writes the specified HubMessage to a string or ArrayBuffer and returns it.

Operators

operator ==(Object other) → bool
The equality operator.
inherited