StreamItemMessage class

A hub message representing a single item produced as part of a result stream.

Inheritance

Constructors

StreamItemMessage({Object? item, MessageHeaders? headers, String? invocationId})

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → MessageHeaders
A {@link @microsoft/signalr.MessageHeaders} dictionary containing headers attached to the message.
finalinherited
invocationId → String?
The ID of the invocation relating to this message.
finalinherited
item → Object?
The item produced by the server.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → MessageType
A MessageType value indicating the type of this message.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited