MessagePackHubProtocol class

Implemented types

Constructors

MessagePackHubProtocol()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the protocol. This is used by SignalR to resolve the protocol between the client and server.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transferFormat → TransferFormat
The TransferFormat of the protocol. */
no setteroverride
version → int
The version of the protocol.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseMessages(Object input, Logger? logger) → List<HubMessageBase>
Creates an array of {@link @microsoft/signalr.HubMessage} objects from the specified serialized representation.
override
toString() → String
A string representation of this object.
inherited
writeMessage(HubMessageBase message) → Object
Writes the specified HubMessage to a string or ArrayBuffer and returns it.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createMessageHeaders(List data) → MessageHeaders