SignalRHttpResponse class

Represents an HTTP response.

Constructors

SignalRHttpResponse(int statusCode, {String? statusText = '', Object? content})
Constructs a new instance of HttpResponse with the specified status code.

Properties

content → Object?
May be a string (json) or an Uint8List (binary)
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
The status code of the response.
final
statusText → String?
The status message of the response
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited