WebSocketTransport class

Implemented types

Constructors

WebSocketTransport(AccessTokenFactory? accessTokenFactory, Logger? logger, bool logMessageContent)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onClose ↔ OnClose?
getter/setter pairoverride
onReceive ↔ OnReceive?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String? url, TransferFormat transferFormat) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(Object data) → Future<void>
data: the content. Either a string (json) or Uint8List (binary)
override
stop() → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited